<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="600px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules"  label-width="130px" >
        <el-form-item label="企业名称:" prop="companyId" v-if="state.isAdmin">
          <el-select
              v-model="state.form.companyId"
              filterable
              clearable
              style="width: 100%"
              :disabled="title == '查看' || title == '编辑' || !state.isAdmin"
              @change="selectValueCom"
          >
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="时间:" prop="trainTime" >
          <el-date-picker
              v-model="state.form.trainTime"
              type="date"
              placeholder="请选择"
              style="width: 100%"
              value-format="YYYY-MM-DD"
              :disabled="title == '查看'"

          />
        </el-form-item>
        <el-form-item label="课程名称:" prop="trainName" >
          <el-input v-model="state.form.trainName" placeholder="课程名称" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="组织部门:" prop="deptId" >
          <el-select
              v-model="state.form.deptId"
              placeholder="请选择部门"
              filterable
              clearable
              style="width: 100%"
              :disabled="title == '查看'"
          >
            <el-option
                v-for="item in state.deptList"
                :key="item.deptId"
                :label="item.deptName"
                :value="item.deptId">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="参训对象:" prop="trainObject" >
          <el-input v-model="state.form.trainObject" placeholder="参训对象" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="人数:" prop="num" >
          <el-input v-model="state.form.num"  placeholder="人数" @input="state.form.num = state.form.num.replace(/[^0-9]/g,'')" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="课时:" prop="hour" >
          <el-input v-model="state.form.hour"
                    placeholder="课时"
                    @input="state.form.hour = state.form.hour
                    .replace(/[^0-9.]/g, '')
                    .replace(/(\..*)\./g, '$1')
                    .replace(/^(-?\d+\.?\d*).*/, '$1')"
                    :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="费用预算(元):" prop="money" >
          <el-input v-model="state.form.money"
                    placeholder="费用预算(元)"
                    @input="state.form.money = state.form.money
                    .replace(/[^0-9.]/g, '')
                    .replace(/(\..*)\./g, '$1')
                    .replace(/^(-?\d+\.?\d*).*/, '$1')"
                    :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="培训形式:" prop="modality" >
          <el-input v-model="state.form.modality" placeholder="培训形式" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="是否已完成:" prop="status" >
          <el-radio-group v-model="state.form.status">
            <el-radio :label="0">是</el-radio>
            <el-radio :label="1">否</el-radio>
          </el-radio-group>
        </el-form-item>
      </el-form>
      <template #footer v-if="title !== '查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"   @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {onMounted, reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail} from "@/api/backManage/evaluate";
import {addCompany, checkName, distributeCompany, editCompany, getCompany} from "@/api/onlineEducation/company";
import {verifyPhone} from "@/utils/validate";
import {addBasic, editBasic} from "@/api/companyInfo/basicInfo";
import Cookies from "js-cookie";
import {getUser} from "@/api/onlineEducation/user";
import {addScenario, editScenario} from "@/api/selfProblems/scenario";
import {addTrainPlan, editTrainPlan} from "@/api/onlineEducation/trainPlan";
import {getDept} from "@/api/qualityObjectives/object";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const state = reactive({
  form: {
    id: '',
    companyId: null,
    trainName: "",
    trainTime: "",
    deptId: null,
    trainObject: "",
    num: "",
    hour: "",
    money: "",
    modality: "",
    status: 3,
  },
  formRules:{
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    trainName: [{ required: true, message: '请输入课程名称', trigger: 'blur' }],
    trainTime:[{ required: true, message: '请选择日期', trigger: 'blur' }],
  },
  isAdmin: false,
  companyList: [],
  deptList: [],
})

onMounted(() => {

})
const openDialog = async (type, value,companyList) => {

  const userInfo = JSON.parse(Cookies.get('userInfo'))
  state.isAdmin = userInfo.userType === 0;
  state.form.companyName = userInfo.companyName
  state.form.companyId = userInfo.companyId
  if(state.isAdmin){
   state.companyList = companyList
    state.form.companyId = value.companyId
    state.form.companyName = value.companyName
  }
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
  if(type === 'edit' || type === 'review') {
    state.form = JSON.parse(JSON.stringify(value));
    if(state.isAdmin){
      state.form.companyId = value.companyId
      state.form.companyName = value.companyName
    }
  }
  await getDeptList()
  dialogVisible.value = true;
}

const getDeptList = async () =>{
  if(state.isAdmin && (state.form.companyId == 0 || state.form.companyId == null)){
    return
  }
  const param = {
    pageNum: 1,
    pageSize: 999,
    companyId: state.form.companyId
  }
  const res = await getDept(param)
  if(res.code === 200){
    state.deptList = res.data
  }
}
const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(!state.isAdmin){
    const userInfo = JSON.parse(Cookies.get('userInfo'))
    state.form.companyId = userInfo.companyId
  }
  if(valid){
    if(title.value === '新增'){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addTrainPlan(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editTrainPlan(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const selectValueCom = (val) => {
  state.form.deptId = null
  getDeptList()
}
const reset = () => {
  state.form = {
    id: '',
    companyId: null,
    trainName: "",
    trainTime: "",
    deptId: null,
    trainObject: "",
    num: "",
    hour: "",
    money: "",
    modality: "",
    status: 3,
  }
  state.companyList = []
  state.deptList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
